pytest-8.4.2
=======================================

pytest 8.4.2 has just been released to PyPI.

This is a bug-fix release, being a drop-in replacement.

The full changelog is available at https://docs.pytest.org/en/stable/changelog.html.

Thanks to all of the contributors to this release:

* AD
* Aditi De
* Bruno Oliveira
* Freya Bruhin
* John Litborn
* Liam DeVoe
* Marc Mueller
* NayeemJohn
* Olivier Grisel
* Ran Benita
* bengartner
* 🇺🇦 Sviatoslav Sydorenko (Святослав Сидоренко)


Happy testing,
The pytest Development Team
